@@ -2,11 +2,7 @@
 Adapted from "The Color Blind Simulation function" by Matthew Wickline
 and the Human - Computer Interaction Resource Network (http://hcirn.com/), 2000 - 2001.
 """
-import matplotlib.image as mpimg
 import numpy as np
-import pandas as pd
-
-from distinctipy import distinctipy
 
 rBlind = {
     "protan": {"cpu": 0.735, "cpv": 0.265, "am": 1.273463, "ayi": -0.073894},
@@ -28,7 +24,6 @@ def rgb2xyz(rgb):
 
 
 def xyz2rgb(xyz):
-
     x = xyz[0]
     y = xyz[1]
     z = xyz[2]
@@ -66,7 +61,7 @@ def blindMK(rgb, t):
     g = rgb[1]
     b = rgb[2]
 
-    c_rgb = (r ** gamma, g ** gamma, b ** gamma)
+    c_rgb = (r**gamma, g**gamma, b**gamma)
     c_xyz = rgb2xyz(c_rgb)
 
     sum_xyz = sum(c_xyz)
@@ -168,19 +163,21 @@ def simulate_image(img_path, colorblind_type):
     :param img_path:
 
     :param colorblind_type: Type of colourblindness to simulate, can be:
-        'Normal': Normal vision
-        'Protanopia': Red-green colorblindness (1% males)
-        'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
-        'Deuteranopia': Red-green colorblindness (1% males)
-        'Deuteranomaly': Red-green colorblindness (most common type: 6% males, 0.4%
-                         females)
-        'Tritanopia': Blue-yellow colourblindness (<1% males and females)
-        'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
-        'Achromatopsia': Total colourblindness
-        'Achromatomaly': Total colourblindness
+
+        * 'Normal': Normal vision
+        * 'Protanopia': Red-green colorblindness (1% males)
+        * 'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
+        * 'Deuteranopia': Red-green colorblindness (1% males)
+        * 'Deuteranomaly': Red-green colorblindness (most common type: 6% males,
+          0.4% females)
+        * 'Tritanopia': Blue-yellow colourblindness (<1% males and females)
+        * 'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
+        * 'Achromatopsia': Total colourblindness
+        * 'Achromatomaly': Total colourblindness
 
     :return:
     """
+    import matplotlib.image as mpimg
     import matplotlib.pyplot as plt
 
     filter_function = fBlind[colorblind_type]
@@ -217,16 +214,17 @@ def colorblind_filter(color, colorblind_type="Deuteranomaly"):
     :param color: rgb colour tuple to convert
 
     :param colorblind_type: Type of colourblindness to simulate, can be:
-        'Normal': Normal vision
-        'Protanopia': Red-green colorblindness (1% males)
-        'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
-        'Deuteranopia': Red-green colorblindness (1% males)
-        'Deuteranomaly': Red-green colorblindness (most common type: 6% males,
-                         0.4% females)
-        'Tritanopia': Blue-yellow colourblindness (<1% males and females)
-        'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
-        'Achromatopsia': Total colourblindness
-        'Achromatomaly': Total colourblindness
+
+        * 'Normal': Normal vision
+        * 'Protanopia': Red-green colorblindness (1% males)
+        * 'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
+        * 'Deuteranopia': Red-green colorblindness (1% males)
+        * 'Deuteranomaly': Red-green colorblindness (most common type: 6% males,
+          0.4% females)
+        * 'Tritanopia': Blue-yellow colourblindness (<1% males and females)
+        * 'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
+        * 'Achromatopsia': Total colourblindness
+        * 'Achromatomaly': Total colourblindness
 
     :return:
     """
@@ -235,32 +233,37 @@ def colorblind_filter(color, colorblind_type="Deuteranomaly"):
     return filter_function(color)
 
 
-def simulate_colors(colors, colorblind_type="Deuteranomaly", one_row=None):
+def simulate_colors(colors, colorblind_type="Deuteranomaly", one_row=None, show=True):
     """
     Simulate the appearance of colors with and without colourblindness.
 
     :param colors: A list of (r,g,b) colour tuples, with r, g andb floats between 0
-    and 1.
+        and 1.
 
     :param colorblind_type: Type of colourblindness to simulate, can be:
-        'Normal': Normal vision
-        'Protanopia': Red-green colorblindness (1% males)
-        'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
-        'Deuteranopia': Red-green colorblindness (1% males)
-        'Deuteranomaly': Red-green colorblindness (most common type: 6% males,
-                         0.4% females)
-        'Tritanopia': Blue-yellow colourblindness (<1% males and females)
-        'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
-        'Achromatopsia': Total colourblindness
-        'Achromatomaly': Total colourblindness
+
+        * 'Normal': Normal vision
+        * 'Protanopia': Red-green colorblindness (1% males)
+        * 'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
+        * 'Deuteranopia': Red-green colorblindness (1% males)
+        * 'Deuteranomaly': Red-green colorblindness (most common type: 6% males,
+          0.4% females)
+        * 'Tritanopia': Blue-yellow colourblindness (<1% males and females)
+        * 'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
+        * 'Achromatopsia': Total colourblindness
+        * 'Achromatomaly': Total colourblindness
 
     :param one_row: If True display colours on one row, if False as a grid. If
-    one_row=None a grid is used when there are more than 8 colours.
+        one_row=None a grid is used when there are more than 8 colours.
+
+    :param show: if True, calls ``plt.show()``.
 
     :return:
     """
     import matplotlib.pyplot as plt
 
+    from distinctipy import distinctipy
+
     filtered_colors = [colorblind_filter(color, colorblind_type) for color in colors]
 
     fig, axes = plt.subplots(1, 2, figsize=(8, 4))
@@ -276,17 +279,22 @@ def simulate_colors(colors, colorblind_type="Deuteranomaly", one_row=None):
         title="Viewed with " + colorblind_type + " Colour Blindness",
     )
 
-    plt.show()
+    if show:
+        plt.show()
 
 
 def simulate_clusters(
-    dataset="s2", colorblind_type="Deuteranomaly", colorblind_distinct=False
+    dataset="s2",
+    colorblind_type="Deuteranomaly",
+    colorblind_distinct=False,
+    show=True,
 ):
     """
     Simulates the appearance of an example clustering dataset with and without
     colourblindness.
 
     :param dataset: The dataset to display, the options are:
+
         * s1, s2, s3, s4: 15 clusters with increasing overlaps from s1 to s4
         * a1: 20 clusters
         * a2: 35 clusters
@@ -294,24 +302,30 @@ def simulate_clusters(
         * b1: 100 clusters
 
     :param colorblind_type: Type of colourblindness to simulate, can be:
-        'Normal': Normal vision
-        'Protanopia': Red-green colorblindness (1% males)
-        'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
-        'Deuteranopia': Red-green colorblindness (1% males)
-        'Deuteranomaly': Red-green colorblindness (most common type: 6% males,
-                         0.4% females)
-        'Tritanopia': Blue-yellow colourblindness (<1% males and females)
-        'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
-        'Achromatopsia': Total colourblindness
-        'Achromatomaly': Total colourblindness
+
+        * 'Normal': Normal vision
+        * 'Protanopia': Red-green colorblindness (1% males)
+        * 'Protanomaly': Red-green colorblindness (1% males, 0.01% females)
+        * 'Deuteranopia': Red-green colorblindness (1% males)
+        * 'Deuteranomaly': Red-green colorblindness (most common type: 6% males,
+          0.4% females)
+        * 'Tritanopia': Blue-yellow colourblindness (<1% males and females)
+        * 'Tritanomaly' Blue-yellow colourblindness (0.01% males and females)
+        * 'Achromatopsia': Total colourblindness
+        * 'Achromatomaly': Total colourblindness
 
     :param colorblind_distinct: If True generate colours to be as distinct as possible
-    for colorblind_type. Else generate colours that are as distinct as possible for
-    normal vision.
+        for colorblind_type. Else generate colours that are as distinct as possible for
+        normal vision.
+
+    :param show: if True, calls ``plt.show()``.
 
     :return:
     """
     import matplotlib.pyplot as plt
+    import pandas as pd
+
+    from distinctipy import distinctipy
 
     if dataset not in ("s1", "s2", "s3", "s4", "a1", "a2", "a3", "b1"):
         raise ValueError("dataset must be s1, s2, s3, s4, a1, a2, a3 or b1")
@@ -350,9 +364,16 @@ def simulate_clusters(
     axes[1].get_yaxis().set_visible(False)
     axes[1].set_title("With " + colorblind_type + " Colourblindness")
 
-    plt.show()
+    if show:
+        plt.show()
+
+
+def _main():
+    from distinctipy import distinctipy
+
+    colors = distinctipy.get_colors(36)
+    simulate_colors(colors, "Deuteranomaly")
 
 
 if __name__ == "__main__":
-    colors = distinctipy.get_colors(36)
-    simulate_colors(colors, "Deuteranomaly")
+    _main()
